ErrorFault class final

Represents a fault caused by an Error

Inheritance

Constructors

ErrorFault(Object error, StackTrace stackTrace)
Creates an ErrorFault with the given error and stackTrace
const

Properties

error → Object
The underlying error
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stack trace associated with this fault
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited