ExceptionFault class final

Represents a fault caused by an Exception

Inheritance

Constructors

ExceptionFault(Exception exception, StackTrace stackTrace)
Creates an ExceptionFault with the given exception and stackTrace
const

Properties

exception → Exception
The underlying exception
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stack trace associated with this fault
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited