UnknownFault class final

Represents an unknown fault type

Inheritance

Constructors

UnknownFault(Object? object, StackTrace stackTrace)
Creates an UnknownFault with the given object and stackTrace
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
object → Object?
The unknown object that caused the fault
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stack trace associated with this fault
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited